==> textacy-0.7.1.tar.gz: textacy-0.7.1/README.md <==
## textacy: NLP, before and after spaCy

textacy is a Python library for performing a variety of natural language
processing (NLP) tasks, built on the high-performance spaCy library. With the
fundamentals --- tokenization, part-of-speech tagging, dependency parsing, etc. ---
delegated to another library, textacy focuses primarily on the tasks
that come before and follow after.

[![build status](https://img.shields.io/travis/chartbeat-labs/textacy/master.svg?style=flat-square)](https://travis-ci.org/chartbeat-labs/textacy)
[![current release version](https://img.shields.io/github/release/chartbeat-labs/textacy.svg?style=flat-square)](https://github.com/chartbeat-labs/textacy/releases)
[![pypi version](https://img.shields.io/pypi/v/textacy.svg?style=flat-square)](https://pypi.python.org/pypi/textacy)
[![conda version](https://anaconda.org/conda-forge/textacy/badges/version.svg)](https://anaconda.org/conda-forge/textacy)

### Features

- Convenient entry points to working with one or many documents processed by spaCy, with functionality added via custom extensions
- Variety of downloadable datasets with both text content and metadata, from Congressional speeches to historical literature to Reddit comments
- Easy file I/O for streaming data to and from disk
- Cleaning, normalization, and exploration of raw text — before processing
- Flexible extraction of words, ngrams, noun chunks, entities, acronyms, key terms, and other elements of interest
- Tokenization and vectorization of documents, with functionality for training, interpreting, and visualizing topic models
- String, set, and document similarity comparison by a variety of metrics
- Calculations for common text statistics, including Flesch-Kincaid Grade Level and multilingual Flesch Reading Ease

... *and more!*


### Links

- PyPi project: https://pypi.org/project/textacy
- Source code: https://github.com/chartbeat-labs/textacy
- Documentation: https://chartbeat-labs.github.io/textacy


### Maintainer

Howdy, y'all. 👋

- Burton DeWilde (<burton@chartbeat.com>)

==> textacy-0.9.1.tar.gz: textacy-0.9.1/README.md <==
## textacy: NLP, before and after spaCy

textacy is a Python library for performing a variety of natural language processing (NLP) tasks, built on the high-performance spaCy library. With the fundamentals --- tokenization, part-of-speech tagging, dependency parsing, etc. --- delegated to another library, textacy focuses primarily on the tasks that come before and follow after.

[![build status](https://img.shields.io/travis/chartbeat-labs/textacy/master.svg?style=flat-square)](https://travis-ci.org/chartbeat-labs/textacy)
[![current release version](https://img.shields.io/github/release/chartbeat-labs/textacy.svg?style=flat-square)](https://github.com/chartbeat-labs/textacy/releases)
[![pypi version](https://img.shields.io/pypi/v/textacy.svg?style=flat-square)](https://pypi.python.org/pypi/textacy)
[![conda version](https://anaconda.org/conda-forge/textacy/badges/version.svg)](https://anaconda.org/conda-forge/textacy)

### Features

- Convenient entry points to working with one or many documents processed by spaCy, with functionality added via custom extensions and automatic language identification for applying the right spaCy pipeline
- Variety of downloadable datasets with both text content and metadata, from Congressional speeches to historical literature to Reddit comments
- Easy file I/O for streaming data to and from disk
- Cleaning, normalization, and exploration of raw text — before processing
- Flexible extraction of words, ngrams, noun chunks, entities, acronyms, key terms, and other elements of interest
- Tokenization and vectorization of documents, with functionality for training, interpreting, and visualizing topic models
- String, set, and document similarity comparison by a variety of metrics
- Calculations for common text statistics, including Flesch-Kincaid Grade Level and multilingual Flesch Reading Ease

... *and more!*


### Links

- Download: https://pypi.org/project/textacy
- Documentation: https://chartbeat-labs.github.io/textacy
- Source code: https://github.com/chartbeat-labs/textacy
- Bug Tracker: https://github.com/chartbeat-labs/textacy/issues


### Maintainer

Howdy, y'all. 👋

- Burton DeWilde (<burton@chartbeat.com>)
